@@ -243,8 +243,10 @@ collect_mysql_data_one() {
    # get and keep a connection to the database; in troubled times
    # the database tends to exceed max_connections, so reconnecting
    # in the loop tends not to work very well.
-   $CMD_MYSQLADMIN $EXT_ARGV ext -i$OPT_SLEEP_COLLECT -c$cnt >>"$d/$p-mysqladmin" &
-   mysqladmin_pid=$!
+   if ! _should_skip "mysqladmin"; then
+      $CMD_MYSQLADMIN $EXT_ARGV ext -i$OPT_SLEEP_COLLECT -c$cnt >>"$d/$p-mysqladmin" &
+      mysqladmin_pid=$!
+   fi
 
    ps_instrumentation_enabled=$($CMD_MYSQL $EXT_ARGV -e 'SELECT ENABLED FROM performance_schema.setup_instruments WHERE NAME = "transaction";' \
                                       | sed "2q;d" | sed 'y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/')
@@ -286,14 +288,28 @@ collect_system_data() {
 }
 
 collect_mysql_data_loop() {
-   (echo $ts; $CMD_MYSQL $EXT_ARGV -e "SHOW FULL PROCESSLIST\G") \
+
+   # SHOW FULL PROCESSLIST duplicates information in performance_schema.threads we collecting now
+   # Keeping it for backward compatibility and may remove in the future
+   if ! _should_skip "processlist"; then
+      (echo $ts; $CMD_MYSQL $EXT_ARGV -e "SHOW FULL PROCESSLIST\G") \
       >> "$d/$p-processlist" &
-   if [ "$have_lock_waits_table" ]; then
-      (echo $ts; lock_waits "$d/lock_waits.running")   >>"$d/$p-lock-waits" &
-      (echo $ts; transactions) >>"$d/$p-transactions" &
    fi
 
-   if [ "${mysql_version}" '>' "5.6" ] && [ $ps_instrumentation_enabled == "yes" ]; then
+   (echo $ts; $CMD_MYSQL $EXT_ARGV -e "SELECT * FROM performance_schema.threads\G") \
+   >> "$d/$p-threads" &
+
+   if [ "$have_lock_waits_table" ]; then
+      if ! _should_skip "lock-waits"; then
+         (echo $ts; lock_waits "$d/lock_waits.running")   >>"$d/$p-lock-waits" &
+      fi
+      if ! _should_skip "transactions"; then
+         (echo $ts; transactions) >>"$d/$p-transactions" &
+      fi
+   fi
+
+   if [ "${mysql_version}" '>' "5.6" ] && [ $ps_instrumentation_enabled == "yes" ] \
+      && ! _should_skip "ps-locks-transactions"; then
       ps_locks_transactions "$d/$p-ps-locks-transactions"
    fi
 
@@ -301,7 +317,11 @@ collect_mysql_data_loop() {
       (echo $ts; ps_prepared_statements "$d/prepared_statements.isrunnning") >> "$d/$p-prepared-statements" &
    fi
 
-   slave_status "$d/$p-slave-status" "${mysql_version}"
+   local replica_name='replica'
+   if [ "${mysql_version}" '<' "8.1" ]; then
+      replica_name="slave"
+   fi
+   replica_status "$d/$p-${replica_name}-status" "${mysql_version}"
 }
 
 collect_system_data_loop() {
@@ -527,20 +547,22 @@ innodb_status() {
 
    local innostat=""
 
-   $CMD_MYSQL $EXT_ARGV -e "SHOW /*!40100 ENGINE*/ INNODB STATUS\G" \
-      >> "$d/$p-innodbstatus$n"
-   grep "END OF INNODB" "$d/$p-innodbstatus$n" >/dev/null || {
-      if [ -d /proc -a -d /proc/$mysqld_pid ]; then
-         for fd in /proc/$mysqld_pid/fd/*; do
-            file $fd | grep deleted >/dev/null && {
-               grep 'INNODB' $fd >/dev/null && {
-                  cat $fd > "$d/$p-innodbstatus$n"
-                  break
+   if ! _should_skip "innodbstatus"; then
+      $CMD_MYSQL $EXT_ARGV -e "SHOW /*!40100 ENGINE*/ INNODB STATUS\G" \
+         >> "$d/$p-innodbstatus$n"
+      grep "END OF INNODB" "$d/$p-innodbstatus$n" >/dev/null || {
+         if [ -d /proc -a -d /proc/$mysqld_pid ]; then
+            for fd in /proc/$mysqld_pid/fd/*; do
+               file $fd | grep deleted >/dev/null && {
+                  grep 'INNODB' $fd >/dev/null && {
+                     cat $fd > "$d/$p-innodbstatus$n"
+                     break
+                  }
                }
-            }
-         done
-      fi
-   }
+            done
+         fi
+      }
+   fi
 }
 
 rocksdb_status() {
@@ -549,7 +571,7 @@ rocksdb_status() {
     has_rocksdb=`$CMD_MYSQL $EXT_ARGV -e "SHOW ENGINES" | grep -i 'rocksdb'`
     exit_code=$?
 
-    if [ $exit_code -eq 0 ]; then
+    if [ $exit_code -eq 0 ] && ! _should_skip "rocksdbstatus"; then
         $CMD_MYSQL $EXT_ARGV -e "SHOW ENGINE ROCKSDB STATUS\G" \
                    >> "$d/$p-rocksdbstatus$n" || rm -f "$d/$p-rocksdbstatus$n"
     fi
@@ -600,14 +622,13 @@ ps_prepared_statements() {
    fi
 }
 
-slave_status() {
+replica_status() {
    local outfile=$1
    local mysql_version=$2
 
+   local sql="SHOW REPLICA STATUS\G"
    if [ "${mysql_version}" '<' "8.1" ]; then
-      local sql="SHOW SLAVE STATUS\G"
-   else
-      local sql="SHOW REPLICA STATUS\G"
+      sql="SHOW SLAVE STATUS\G"
    fi
 
    echo -e "\n$sql\n" >> $outfile
@@ -636,20 +657,34 @@ collect_mysql_variables() {
    echo -e "\n$sql\n" >> $outfile
    $CMD_MYSQL $EXT_ARGV -e "$sql" >> $outfile
 
-   sql="select * from performance_schema.variables_by_thread order by thread_id, variable_name;"
-   echo -e "\n$sql\n" >> $outfile
-   $CMD_MYSQL $EXT_ARGV -e "$sql" >> $outfile
+   if ! _should_skip "thread-variables"; then
+      sql="select * from performance_schema.variables_by_thread order by thread_id, variable_name;"
+      echo -e "\n$sql\n" >> $outfile
+      $CMD_MYSQL $EXT_ARGV -e "$sql" >> $outfile
 
-   sql="select * from performance_schema.user_variables_by_thread order by thread_id, variable_name;"
-   echo -e "\n$sql\n" >> $outfile
-   $CMD_MYSQL $EXT_ARGV -e "$sql" >> $outfile
+      sql="select * from performance_schema.user_variables_by_thread order by thread_id, variable_name;"
+      echo -e "\n$sql\n" >> $outfile
+      $CMD_MYSQL $EXT_ARGV -e "$sql" >> $outfile
 
-   sql="select * from performance_schema.status_by_thread order by thread_id, variable_name; "
-   echo -e "\n$sql\n" >> $outfile
-   $CMD_MYSQL $EXT_ARGV -e "$sql" >> $outfile
+      sql="select * from performance_schema.status_by_thread order by thread_id, variable_name; "
+      echo -e "\n$sql\n" >> $outfile
+      $CMD_MYSQL $EXT_ARGV -e "$sql" >> $outfile
+   fi
 
 }
 
+_should_skip() {
+   local name=$1
+
+   for item in "${OPT_SKIP_COLLECTION[@]}"; do
+      if [ "$item" == "$name" ]; then
+         return 0
+      fi
+   done
+
+   return 1
+}
+
 # ###########################################################################
 # End collect package
 # ###########################################################################
