@@ -201,6 +201,26 @@ var ApplicativeMap = types.RegexMap{
 		},
 		Verbosity: types.DebugMySQL,
 	},
+
+	"RegexInconsistencyVoteRecomputed": &types.LogRegex{
+		Regex:         regexp.MustCompile("Recomputed vote based on error codes"),
+		InternalRegex: regexp.MustCompile("New vote " + regexErrorMD5 + " will be used.*Old Vote: (?P<" + groupErrorMD5 + "2" + ">[a-z0-9]*)"),
+		Handler: func(submatches map[string]string, logCtx types.LogCtx, log string, date time.Time) (types.LogCtx, types.LogDisplayer) {
+			oldMD5 := submatches[groupErrorMD5+"2"]
+			md5 := submatches[groupErrorMD5]
+
+			for _, conflict := range logCtx.Conflicts {
+				for node, vote := range conflict.VotePerNode {
+					if vote.MD5 == oldMD5 {
+						vote.MD5 = md5
+						conflict.VotePerNode[node] = vote
+					}
+				}
+			}
+			return logCtx, types.SimpleDisplayer("vote md5 recomputed from " + oldMD5 + " to " + md5)
+		},
+		Verbosity: types.DebugMySQL,
+	},
 }
 
 func voteResponse(vote types.ConflictVote, conflict types.Conflict) string {
