@@ -18,8 +18,8 @@ CREATE TABLE IF NOT EXISTS percona.checksums (
    upper_boundary TEXT             NULL,
    this_crc       CHAR(40)     NOT NULL,
    this_cnt       INT          NOT NULL,
-   master_crc     CHAR(40)         NULL,
-   master_cnt     INT              NULL,
+   source_crc     CHAR(40)         NULL,
+   source_cnt     INT              NULL,
    ts             TIMESTAMP    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (db, tbl, chunk),
    INDEX ts_db_tbl (ts, db, tbl)
